@@ -8,6 +8,8 @@
 #' Deque$pushleft(item)
 #' Deque$pop()
 #' Deque$popleft()
+#' Deque$peek()
+#' Deque$peekleft()
 #' Deque$extend(q)
 #' Deque$extendleft(q)
 #' Deque$remove(item)
@@ -49,6 +51,14 @@ Deque <- R6::R6Class("Deque",
         popleft = function() {
             .Call("deque_popleft", PACKAGE = "collections", private)
         },
+        peek = function() {
+            if (is.null(private$last)) stop("deque is empty")
+            .Call("pairlist_car", PACKAGE = "collections", private$last)[[2]]
+        },
+        peekleft = function() {
+            if (is.null(private$q)) stop("deque is empty")
+            .Call("pairlist_car", PACKAGE = "collections", private$q)[[2]]
+        },
         extend = function(deque) {
             !inherits(deque, "Deque") && stop("expect Deque object")
             q <- deque$.__enclos_env__$private$q
@@ -103,6 +113,8 @@ Deque <- R6::R6Class("Deque",
 #' DequeL$pushleft(item)
 #' DequeL$pop()
 #' DequeL$popleft()
+#' DequeL$peek()
+#' DequeL$peekleft()
 #' DequeL$extend(q)
 #' DequeL$extendleft(q)
 #' DequeL$clear()
@@ -156,6 +168,14 @@ DequeL <- R6::R6Class("DequeL",
             private$n <- private$n - 1
             v
         },
+        peek = function() {
+            if (private$n == 0) stop("deque is empty")
+            private$q[[private$n]]
+        },
+        peekleft = function() {
+            if (private$n == 0) stop("deque is empty")
+            private$q[[1]]
+        },
         extend = function(deque) {
             !inherits(deque, "DequeL") && stop("expect DequeL object")
             q <- deque$.__enclos_env__$private$q
