@@ -1,34 +1,42 @@
 context("Deque")
 
-test_that("push and pop", {
+test_that("push, peek and pop", {
     q <- Deque$new()
     q$push(1)
     q$push(2)
     expect_equal(q$size(), 2)
+    expect_equal(q$peek(), 2)
     expect_equal(q$pop(), 2)
     expect_equal(q$size(), 1)
     q$push(3)
     expect_equal(q$size(), 2)
+    expect_equal(q$peek(), 3)
     expect_equal(q$pop(), 3)
+    expect_equal(q$peek(), 1)
     expect_equal(q$pop(), 1)
     expect_equal(q$size(), 0)
+    expect_error(q$peek(), "empty")
     expect_error(q$pop(), "empty")
 })
 
 
-test_that("push and pop", {
+test_that("push, peek and pop", {
     q <- Deque$new()
     q$pushleft(1)
     q$pushleft(2)
     expect_equal(q$size(), 2)
+    expect_equal(q$peekleft(), 2)
     expect_equal(q$popleft(), 2)
     expect_equal(q$size(), 1)
     q$pushleft(3)
     expect_equal(q$size(), 2)
+    expect_equal(q$peekleft(), 3)
     expect_equal(q$popleft(), 3)
+    expect_equal(q$peekleft(), 1)
     expect_equal(q$popleft(), 1)
     expect_equal(q$size(), 0)
-    expect_error(q$pop(), "empty")
+    expect_error(q$popleft(), "empty")
+    expect_error(q$peekleft(), "empty")
 })
 
 test_that("random push and pop", {
@@ -108,35 +116,43 @@ test_that("clear", {
 
 context("DequeL")
 
-test_that("push and pop", {
+test_that("push, peek and pop", {
     q <- DequeL$new()
     q$push(1)
     q$push(2)
     expect_equal(q$size(), 2)
+    expect_equal(q$peek(), 2)
     expect_equal(q$pop(), 2)
     expect_equal(q$size(), 1)
     q$push(3)
     expect_equal(q$size(), 2)
+    expect_equal(q$peek(), 3)
     expect_equal(q$pop(), 3)
+    expect_equal(q$peek(), 1)
     expect_equal(q$pop(), 1)
     expect_equal(q$size(), 0)
+    expect_error(q$peek(), "empty")
     expect_error(q$pop(), "empty")
 })
 
 
-test_that("push and pop", {
+test_that("push, peek and pop", {
     q <- DequeL$new()
     q$pushleft(1)
     q$pushleft(2)
     expect_equal(q$size(), 2)
+    expect_equal(q$peekleft(), 2)
     expect_equal(q$popleft(), 2)
     expect_equal(q$size(), 1)
     q$pushleft(3)
     expect_equal(q$size(), 2)
+    expect_equal(q$peekleft(), 3)
     expect_equal(q$popleft(), 3)
+    expect_equal(q$peekleft(), 1)
     expect_equal(q$popleft(), 1)
     expect_equal(q$size(), 0)
-    expect_error(q$pop(), "empty")
+    expect_error(q$peekleft(), "empty")
+    expect_error(q$popleft(), "empty")
 })
 
 test_that("random push and pop", {
