@@ -1,17 +1,21 @@
 context("Queue")
 
-test_that("push and pop", {
+test_that("push, peek and pop", {
     q <- Queue$new()
     q$push(1)
     q$push(2)
     expect_equal(q$size(), 2)
+    expect_equal(q$peek(), 1)
     expect_equal(q$pop(), 1)
     expect_equal(q$size(), 1)
     q$push(3)
     expect_equal(q$size(), 2)
+    expect_equal(q$peek(), 2)
     expect_equal(q$pop(), 2)
+    expect_equal(q$peek(), 3)
     expect_equal(q$pop(), 3)
     expect_equal(q$size(), 0)
+    expect_error(q$peek(), "empty")
     expect_error(q$pop(), "empty")
 })
 
@@ -27,18 +31,22 @@ test_that("clear", {
 
 context("QueueL")
 
-test_that("push and pop", {
+test_that("push, peek and pop", {
     q <- QueueL$new()
     q$push(1)
     q$push(2)
     expect_equal(q$size(), 2)
+    expect_equal(q$peek(), 1)
     expect_equal(q$pop(), 1)
     expect_equal(q$size(), 1)
     q$push(3)
     expect_equal(q$size(), 2)
+    expect_equal(q$peek(), 2)
     expect_equal(q$pop(), 2)
+    expect_equal(q$peek(), 3)
     expect_equal(q$pop(), 3)
     expect_equal(q$size(), 0)
+    expect_error(q$peek(), "empty")
     expect_error(q$pop(), "empty")
 })
 
